==> BeadDataPackR_1.2.1.zip: BeadDataPackR/doc/BeadDataPackR.R <==
###################################################
### chunk number 1: Loading
###################################################
#line 57 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpQLeXVQ/R.INSTALL3eac65d1/BeadDataPackR/inst/doc/BeadDataPackR.rnw"
    library(BeadDataPackR)
    dataPath <- system.file("data", package = "BeadDataPackR")


###################################################
### chunk number 2: Compress eval=FALSE
###################################################
## #line 64 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpQLeXVQ/R.INSTALL3eac65d1/BeadDataPackR/inst/doc/BeadDataPackR.rnw"
##     compressBeadData(txtFile = "example.txt", locsGrn = "example_Grn.locs", outputFile = "example.bab", path = dataPath, nBytes = 4, nrow = 326, ncol = 4)


###################################################
### chunk number 3: Decompress eval=FALSE
###################################################
## #line 78 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpQLeXVQ/R.INSTALL3eac65d1/BeadDataPackR/inst/doc/BeadDataPackR.rnw"
##     decompressBeadData(inputFile = "example.bab", inputPath = dataPath, outputMask = "restored", outputPath = ".", outputNonDecoded = FALSE, roundValues = TRUE )


###################################################
### chunk number 4: readCompressed eval=FALSE
###################################################
## #line 92 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpQLeXVQ/R.INSTALL3eac65d1/BeadDataPackR/inst/doc/BeadDataPackR.rnw"
##   readCompressedData(inputFile = "example.bab", path = dataPath, probeIDs = c(10008, 10010) )


###################################################
### chunk number 5: extractLocsFile eval=FALSE
###################################################
## #line 100 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpQLeXVQ/R.INSTALL3eac65d1/BeadDataPackR/inst/doc/BeadDataPackR.rnw"
##   locs <- extractLocsFile(inputFile = "example.bab", path = dataPath)


###################################################
### chunk number 6: sessionInfo
###################################################
#line 111 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpQLeXVQ/R.INSTALL3eac65d1/BeadDataPackR/inst/doc/BeadDataPackR.rnw"
toLatex(sessionInfo())

==> BeadDataPackR_1.4.0.zip: BeadDataPackR/doc/BeadDataPackR.R <==
###################################################
### chunk number 1: Loading
###################################################
#line 57 "BeadDataPackR.rnw"
    library(BeadDataPackR)
    dataPath <- system.file("extdata", package = "BeadDataPackR")


###################################################
### chunk number 2: Compress eval=FALSE
###################################################
## #line 64 "BeadDataPackR.rnw"
##     compressBeadData(txtFile = "example.txt", locsGrn = "example_Grn.locs", outputFile = "example.bab", path = dataPath, nBytes = 4, nrow = 326, ncol = 4)


###################################################
### chunk number 3: Decompress eval=FALSE
###################################################
## #line 78 "BeadDataPackR.rnw"
##     decompressBeadData(inputFile = "example.bab", inputPath = dataPath, outputMask = "restored", outputPath = ".", outputNonDecoded = FALSE, roundValues = TRUE )


###################################################
### chunk number 4: readCompressed eval=FALSE
###################################################
## #line 92 "BeadDataPackR.rnw"
##   readCompressedData(inputFile = "example.bab", path = dataPath, probeIDs = c(10008, 10010) )


###################################################
### chunk number 5: extractLocsFile eval=FALSE
###################################################
## #line 100 "BeadDataPackR.rnw"
##   locs <- extractLocsFile(inputFile = "example.bab", path = dataPath)


###################################################
### chunk number 6: sessionInfo
###################################################
#line 111 "BeadDataPackR.rnw"
toLatex(sessionInfo())
